@@ -416,7 +416,7 @@ e_cal_view_start (ECalView *view)
 	LOCK_VIEW ();
 	if (!org_gnome_evolution_dataserver_calendar_CalView_start (priv->view_proxy, &error)) {
 		UNLOCK_VIEW ();
-		g_printerr("%s: %s\n", __FUNCTION__, error->message);
+		g_printerr("%s: %s\n", G_STRFUNC, error->message);
 		g_error_free (error);
 		g_warning (G_STRLOC ": Unable to start view");
 		return;
