@@ -4,14 +4,13 @@
  * Author:
  *   Chris Toshok (toshok@ximian.com)
  *
- * Copyright 2004, Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <pthread.h>
 #include <string.h>
 
 #include "e-cal-backend-factory.h"
@@ -74,7 +73,7 @@ e_cal_backend_factory_get_kind (ECalBackendFactory *factory)
  *
  * Return value: The protocol.
  */
-const char*
+const gchar *
 e_cal_backend_factory_get_protocol (ECalBackendFactory *factory)
 {
 	g_return_val_if_fail (E_IS_CAL_BACKEND_FACTORY (factory), NULL);
