@@ -267,10 +267,6 @@ void
 camel_folder_construct (CamelFolder *folder, CamelStore *parent_store,
 			const gchar *full_name, const gchar *name)
 {
-	gchar *store_db_path;
-	CamelService *service = (CamelService *) parent_store;
-	CamelException ex;
-
 	g_return_if_fail (CAMEL_IS_FOLDER (folder));
 	g_return_if_fail (CAMEL_IS_STORE (parent_store));
 	g_return_if_fail (folder->parent_store == NULL);
@@ -282,16 +278,6 @@ camel_folder_construct (CamelFolder *folder, CamelStore *parent_store,
 
 	folder->name = g_strdup (name);
 	folder->full_name = g_strdup (full_name);
-
-	store_db_path = g_build_filename (service->url->path, CAMEL_DB_FILE, NULL);
-	camel_exception_init(&ex);
-	if (strlen (store_db_path) < 2) {
-		gchar *store_path = camel_session_get_storage_path ((CamelSession *)camel_service_get_session (service), service, &ex);
-
-		g_free (store_db_path);
-		store_db_path = g_build_filename (store_path, CAMEL_DB_FILE, NULL);
-		g_free (store_path);
-	}
 }
 
 static void
@@ -1915,16 +1901,17 @@ filter_filter(CamelSession *session, CamelSessionThreadMsg *tmsg)
 	gint i, status = 0;
 	CamelURL *uri;
 	gchar *source_url;
-	CamelException ex;
+	CamelException ex = CAMEL_EXCEPTION_INITIALISER;
 	CamelJunkPlugin *csp = ((CamelService *)m->folder->parent_store)->session->junk_plugin;
 
 	if (m->junk) {
 		camel_operation_start (NULL, _("Learning junk"));
 
 		for (i = 0; i < m->junk->len; i ++) {
-			CamelMimeMessage *msg = camel_folder_get_message(m->folder, m->junk->pdata[i], NULL);
+			CamelMimeMessage *msg = camel_folder_get_message(m->folder, m->junk->pdata[i], &ex);
 			gint pc = 100 * i / m->junk->len;
 
+			camel_exception_clear (&ex);
 			camel_operation_progress(NULL, pc);
 
 			if (msg) {
@@ -1938,9 +1925,10 @@ filter_filter(CamelSession *session, CamelSessionThreadMsg *tmsg)
 	if (m->notjunk) {
 		camel_operation_start (NULL, _("Learning non-junk"));
 		for (i = 0; i < m->notjunk->len; i ++) {
-			CamelMimeMessage *msg = camel_folder_get_message(m->folder, m->notjunk->pdata[i], NULL);
+			CamelMimeMessage *msg = camel_folder_get_message(m->folder, m->notjunk->pdata[i], &ex);
 			gint pc = 100 * i / m->notjunk->len;
 
+			camel_exception_clear (&ex);
 			camel_operation_progress(NULL, pc);
 
 			if (msg) {
@@ -1987,7 +1975,6 @@ filter_filter(CamelSession *session, CamelSessionThreadMsg *tmsg)
 			camel_folder_free_message_info(m->folder, info);
 		}
 
-		camel_exception_init(&ex);
 		camel_filter_driver_flush(m->driver, &ex);
 		if (!camel_exception_is_set(&m->ex))
 			camel_exception_xfer(&m->ex, &ex);
