@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000 Ximian Inc.
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 /* Abstract class for non-copying filters */
@@ -41,15 +41,15 @@ struct _CamelMimeFilter {
 
 	struct _CamelMimeFilterPrivate *priv;
 
-	char *outreal;		/* real malloc'd buffer */
-	char *outbuf;		/* first 'writable' position allowed (outreal + outpre) */
-	char *outptr;
-	size_t outsize;
-	size_t outpre;		/* prespace of this buffer */
+	gchar *outreal;		/* real malloc'd buffer */
+	gchar *outbuf;		/* first 'writable' position allowed (outreal + outpre) */
+	gchar *outptr;
+	gsize outsize;
+	gsize outpre;		/* prespace of this buffer */
 
-	char *backbuf;
-	size_t backsize;
-	size_t backlen;		/* significant data there */
+	gchar *backbuf;
+	gsize backsize;
+	gsize backlen;		/* significant data there */
 };
 
 struct _CamelMimeFilterClass {
@@ -57,11 +57,11 @@ struct _CamelMimeFilterClass {
 
 	/* virtual functions */
 	void (*filter)(CamelMimeFilter *f,
-		       char *in, size_t len, size_t prespace,
-		       char **out, size_t *outlen, size_t *outprespace);
+		       const gchar *in, gsize len, gsize prespace,
+		       gchar **out, gsize *outlen, gsize *outprespace);
 	void (*complete)(CamelMimeFilter *f,
-			 char *in, size_t len, size_t prespace,
-			 char **out, size_t *outlen, size_t *outprespace);
+			 const gchar *in, gsize len, gsize prespace,
+			 gchar **out, gsize *outlen, gsize *outprespace);
 	void (*reset)(CamelMimeFilter *f);
 };
 
@@ -69,20 +69,20 @@ CamelType	      camel_mime_filter_get_type	(void);
 CamelMimeFilter      *camel_mime_filter_new	(void);
 
 void camel_mime_filter_filter(CamelMimeFilter *filter,
-			      char *in, size_t len, size_t prespace,
-			      char **out, size_t *outlen, size_t *outprespace);
+			      const gchar *in, gsize len, gsize prespace,
+			      gchar **out, gsize *outlen, gsize *outprespace);
 
 void camel_mime_filter_complete(CamelMimeFilter *filter,
-				char *in, size_t len, size_t prespace,
-				char **out, size_t *outlen, size_t *outprespace);
+				const gchar *in, gsize len, gsize prespace,
+				gchar **out, gsize *outlen, gsize *outprespace);
 
 void camel_mime_filter_reset(CamelMimeFilter *filter);
 
 /* sets/returns number of bytes backed up on the input */
-void camel_mime_filter_backup(CamelMimeFilter *filter, const char *data, size_t length);
+void camel_mime_filter_backup(CamelMimeFilter *filter, const gchar *data, gsize length);
 
 /* ensure this much size available for filter output */
-void camel_mime_filter_set_size(CamelMimeFilter *filter, size_t size, int keep);
+void camel_mime_filter_set_size(CamelMimeFilter *filter, gsize size, gint keep);
 
 G_END_DECLS
 
