@@ -10,6 +10,7 @@
 
 #include "camel-imapx-folder.h"
 #include "camel-imapx-stream.h"
+#include "camel-imapx-summary.h"
 #include "camel-imapx-store-summary.h"
 #include "camel-imapx-utils.h"
 #include "camel-imapx-exception.h"
@@ -37,10 +38,11 @@ imap_tokenise (register const gchar *str, register guint len)
 }
 
 static void imapx_namespace_clear (CamelIMAPXStoreNamespace **ns);
+static const gchar * rename_label_flag (const gchar *flag, gint len, gboolean server_to_evo);
 
 /* flag table */
 static struct {
-	gchar *name;
+	const gchar *name;
 	guint32 flag;
 } flag_table[] = {
 	{ "\\ANSWERED", CAMEL_MESSAGE_ANSWERED },
@@ -48,8 +50,8 @@ static struct {
 	{ "\\DRAFT", CAMEL_MESSAGE_DRAFT },
 	{ "\\FLAGGED", CAMEL_MESSAGE_FLAGGED },
 	{ "\\SEEN", CAMEL_MESSAGE_SEEN },
-//	{ "\\RECENT", CAMEL_MESSAGE_RECENT },
-	{ "\\*", CAMEL_MESSAGE_USER },
+	{ "\\RECENT", CAMEL_IMAPX_MESSAGE_RECENT },
+	{ "\\*", CAMEL_MESSAGE_USER }
 };
 
 /* utility functions
@@ -80,8 +82,12 @@ imap_parse_flags(CamelIMAPXStream *stream, guint32 *flagsp, CamelFlag **user_fla
 						flags |= flag_table[i].flag;
 						goto found;
 					}
-				if (user_flagsp)
-					camel_flag_set(user_flagsp, (gchar *)token, TRUE);
+				if (user_flagsp) {
+					const gchar *flag_name = rename_label_flag ((gchar *) token, strlen ((gchar *) token), TRUE);
+
+					camel_flag_set(user_flagsp, flag_name, TRUE);
+
+				}
 			found:
 				tok = tok; /* fixes stupid warning */
 			} else if (tok != ')') {
@@ -97,37 +103,269 @@ imap_parse_flags(CamelIMAPXStream *stream, guint32 *flagsp, CamelFlag **user_fla
 	*flagsp = flags;
 }
 
+/*
+ * rename_flag
+ * Converts label flag name on server to name used in Evolution or back.
+ * if the flags does not match returns the original one as it is.
+ * It will never return NULL, it will return empty string, instead.
+ *
+ * @param flag Flag to rename.
+ * @param len Length of the flag name.
+ * @param server_to_evo if TRUE, then converting server names to evo's names, if FALSE then opposite.
+ */
+static const gchar *
+rename_label_flag (const gchar *flag, gint len, gboolean server_to_evo)
+{
+	gint i;
+	const gchar *labels[] = {
+		"$Label1", "$Labelimportant",
+		"$Label2", "$Labelwork",
+		"$Label3", "$Labelpersonal",
+		"$Label4", "$Labeltodo",
+		"$Label5", "$Labellater",
+		NULL,      NULL };
+
+	/* It really can pass zero-length flags inside, in that case it was able
+	   to always add first label, which is definitely wrong. */
+	if (!len || !flag || !*flag)
+		return "";
+
+	for (i = 0 + (server_to_evo ? 0 : 1); labels[i]; i = i + 2) {
+		if (!g_ascii_strncasecmp (flag, labels[i], len))
+			return labels [i + (server_to_evo ? 1 : -1)];
+	}
+
+	return flag;
+}
+
 void
-imap_write_flags(CamelStream *stream, guint32 flags, CamelFlag *user_flags)
+imap_write_flags(CamelStream *stream, guint32 flags, CamelFlag *user_flags, CamelException *ex)
 /* throws IO exception */
 {
 	gint i;
 
-	/* all this ugly exception throwing goes away once camel streams throw their own? */
-	if (camel_stream_write(stream, "(", 1) == -1)
-		camel_exception_throw(1, "io error: %s", strerror(errno));
+	if (camel_stream_write(stream, "(", 1) == -1) {
+		camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
+		return;
+	}
 
 	for (i=0;flags!=0 && i< G_N_ELEMENTS (flag_table);i++) {
 		if (flag_table[i].flag & flags) {
-			if (camel_stream_write(stream, flag_table[i].name, strlen(flag_table[i].name)) == -1)
-				camel_exception_throw(1, "io error: %s", strerror(errno));
+			if (flags & CAMEL_IMAPX_MESSAGE_RECENT)
+				continue;
+
+			if (camel_stream_write (stream, flag_table[i].name, strlen(flag_table[i].name)) == -1) {
+				camel_exception_setv (ex,1, "io error: %s", strerror(errno));
+				return;
+			}
+
 			flags &= ~flag_table[i].flag;
 			if (flags != 0 && user_flags == NULL)
-				if (camel_stream_write(stream, " ", 1) == -1)
-					camel_exception_throw(1, "io error: %s", strerror(errno));
+				if (camel_stream_write(stream, " ", 1) == -1) {
+					camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
+					return;
+				}
 		}
 	}
 
 	while (user_flags) {
-		if (camel_stream_write(stream, user_flags->name, strlen(user_flags->name)) == -1)
-			camel_exception_throw(1, "io error: %s", strerror(errno));
-		if (user_flags->next && camel_stream_write(stream, " ", 1) == -1)
-			camel_exception_throw(1, "io error: %s", strerror(errno));
+		const gchar *flag_name = rename_label_flag (user_flags->name, strlen (user_flags->name), FALSE);
+
+		if (camel_stream_write(stream, flag_name, strlen (flag_name)) == -1) {
+			camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
+			return;
+		}
+
+		if (user_flags->next && camel_stream_write(stream, " ", 1) == -1) {
+			camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
+			return;
+		}
+
 		user_flags = user_flags->next;
 	}
 
-	if (camel_stream_write(stream, ")", 1) == -1)
-		camel_exception_throw(1, "io error: %s", strerror(errno));
+	if (camel_stream_write(stream, ")", 1) == -1) {
+		camel_exception_setv (ex, 1, "io error: %s", strerror(errno));
+		return;
+	}
+}
+
+static gboolean
+imap_update_user_flags (CamelMessageInfo *info, CamelFlag *server_user_flags)
+{
+	gboolean changed = FALSE;
+	CamelMessageInfoBase *binfo = (CamelMessageInfoBase *) info;
+	gboolean set_cal = FALSE;
+
+	if (camel_flag_get (&binfo->user_flags, "$has_cal"))
+		set_cal = TRUE;
+
+	changed = camel_flag_list_copy(&binfo->user_flags, &server_user_flags);
+
+	/* reset the calendar flag if it was set in messageinfo before */
+	if (set_cal)
+		camel_flag_set (&binfo->user_flags, "$has_cal", TRUE);
+
+	return changed;
+}
+
+gboolean
+imap_update_message_info_flags (CamelMessageInfo *info, guint32 server_flags, CamelFlag *server_user_flags, CamelFolder *folder)
+{
+	gboolean changed = FALSE;
+	CamelIMAPXMessageInfo *xinfo = (CamelIMAPXMessageInfo *) info;
+
+	if (server_flags != xinfo->server_flags)
+	{
+		guint32 server_set, server_cleared;
+		gint read=0, deleted=0, junk=0;
+
+		server_set = server_flags & ~xinfo->server_flags;
+		server_cleared = xinfo->server_flags & ~server_flags;
+
+		if (server_set & CAMEL_MESSAGE_SEEN)
+			read = 1;
+		else if (server_cleared & CAMEL_MESSAGE_SEEN)
+			read = -1;
+
+		if (server_set & CAMEL_MESSAGE_DELETED)
+			deleted = 1;
+		else if (server_cleared & CAMEL_MESSAGE_DELETED)
+			deleted = -1;
+
+		if (server_set & CAMEL_MESSAGE_JUNK)
+			junk = 1;
+		else if (server_cleared & CAMEL_MESSAGE_JUNK)
+			junk = -1;
+
+		d(printf("%s %s %s %s\n", xinfo->info.uid, read == 1 ? "read" : ( read == -1 ? "unread" : ""),
+					deleted == 1 ? "deleted" : ( deleted == -1 ? "undeleted" : ""),
+					junk == 1 ? "junk" : ( junk == -1 ? "unjunked" : "")));
+
+		if (read)
+			folder->summary->unread_count -= read;
+		if (deleted)
+			folder->summary->deleted_count += deleted;
+		if (junk)
+			folder->summary->junk_count += junk;
+		if (junk && !deleted)
+			folder->summary->junk_not_deleted_count += junk;
+		if (junk ||  deleted)
+			folder->summary->visible_count -= junk ? junk : deleted;
+
+		xinfo->info.flags = (xinfo->info.flags | server_set) & ~server_cleared;
+		xinfo->server_flags = server_flags;
+		xinfo->info.dirty = TRUE;
+		if (info->summary)
+			camel_folder_summary_touch (info->summary);
+		changed = TRUE;
+	}
+
+	if ((folder->permanent_flags & CAMEL_MESSAGE_USER) != 0 && imap_update_user_flags (info, server_user_flags))
+		changed = TRUE;
+
+	return changed;
+}
+
+void
+imap_set_message_info_flags_for_new_message (CamelMessageInfo *info, guint32 server_flags, CamelFlag *server_user_flags, CamelFolder *folder)
+{
+	CamelMessageInfoBase *binfo = (CamelMessageInfoBase *) info;
+	CamelIMAPXMessageInfo *xinfo = (CamelIMAPXMessageInfo *) info;
+	gint unread=0, deleted=0, junk=0;
+	guint32 flags;
+
+	binfo->flags |= server_flags;
+	xinfo->server_flags = server_flags;
+
+	if (folder->permanent_flags & CAMEL_MESSAGE_USER)
+		imap_update_user_flags (info, server_user_flags);
+
+	/* update the summary count */
+	flags = binfo->flags;
+
+	if (!(flags & CAMEL_MESSAGE_SEEN))
+		unread = 1;
+
+	if (flags & CAMEL_MESSAGE_DELETED)
+		deleted = 1;
+
+	if (flags & CAMEL_MESSAGE_JUNK)
+		junk = 1;
+
+	if (folder->summary) {
+
+		if (unread)
+			folder->summary->unread_count += unread;
+		if (deleted)
+			folder->summary->deleted_count += deleted;
+		if (junk)
+			folder->summary->junk_count += junk;
+		if (junk && !deleted)
+			folder->summary->junk_not_deleted_count += junk;
+		folder->summary->visible_count++;
+		if (junk ||  deleted)
+			folder->summary->visible_count -= junk ? junk : deleted;
+
+		folder->summary->saved_count++;
+		camel_folder_summary_touch(folder->summary);
+	}
+
+	binfo->flags &= ~CAMEL_MESSAGE_FOLDER_FLAGGED;
+}
+
+void
+imap_update_summary_for_removed_message (CamelMessageInfo *info, CamelFolder *folder)
+{
+	CamelMessageInfoBase *dinfo = (CamelMessageInfoBase *) info;
+	gint unread=0, deleted=0, junk=0;
+	guint32 flags;
+
+	flags = dinfo->flags;
+	if (!(flags & CAMEL_MESSAGE_SEEN))
+		unread = 1;
+
+	if (flags & CAMEL_MESSAGE_DELETED)
+		deleted = 1;
+
+	if (flags & CAMEL_MESSAGE_JUNK)
+		junk = 1;
+
+	if (unread)
+		folder->summary->unread_count--;
+
+	if (deleted)
+		folder->summary->deleted_count--;
+	if (junk)
+		folder->summary->junk_count--;
+
+	if (junk && !deleted)
+		folder->summary->junk_not_deleted_count--;
+
+	if (!junk &&  !deleted)
+		folder->summary->visible_count--;
+
+	folder->summary->saved_count--;
+}
+
+void
+imap_update_store_summary (CamelFolder *folder)
+{
+	CamelStoreInfo *si;
+
+	si = camel_store_summary_path ((CamelStoreSummary *) ((CamelIMAPXStore *) folder->parent_store)->summary, folder->full_name);
+	if (si) {
+		guint32 unread, total;
+
+		camel_object_get(folder, NULL, CAMEL_FOLDER_TOTAL, &total, CAMEL_FOLDER_UNREAD, &unread, NULL);
+		if (si->unread != unread || si->total != total) {
+			si->unread = unread;
+			si->total = total;
+
+			camel_store_summary_touch ((CamelStoreSummary *)((CamelIMAPXStore *) folder->parent_store)->summary);
+			camel_store_summary_save ((CamelStoreSummary *)((CamelIMAPXStore *) folder->parent_store)->summary);
+		}
+	}
 }
 
 /*
@@ -139,7 +377,7 @@ capability_data ::= "CAPABILITY" SPACE [1#capability SPACE] "IMAP4rev1"
 */
 
 struct {
-	gchar *name;
+	const gchar *name;
 	guint32 flag;
 } capa_table[] = {
 	{ "IMAP4", IMAP_CAPABILITY_IMAP4 },
@@ -149,13 +387,15 @@ struct {
 	{ "UIDPLUS",  IMAP_CAPABILITY_UIDPLUS },
 	{ "LITERAL+", IMAP_CAPABILITY_LITERALPLUS },
 	{ "STARTTLS", IMAP_CAPABILITY_STARTTLS },
+	{ "IDLE", IMAP_CAPABILITY_IDLE },
 };
 
 struct _capability_info *
 imap_parse_capability(CamelIMAPXStream *stream, CamelException *ex)
 {
-	gint tok, len, i;
-	guchar *token, *p, c, *temp;
+	gint tok, i;
+	guint len;
+	guchar *token, *p, c;
 	gboolean free_token = FALSE;
 	struct _capability_info * cinfo;
 
@@ -165,7 +405,7 @@ imap_parse_capability(CamelIMAPXStream *stream, CamelException *ex)
 	while (!camel_exception_is_set (ex) && (tok = camel_imapx_stream_token(stream, &token, &len, ex)) != '\n') {
 		switch (tok) {
 			case 43:
-				token = g_strconcat (token, "+", NULL);
+				token = (guchar *) g_strconcat ((gchar *)token, "+", NULL);
 				free_token = TRUE;
 			case IMAP_TOK_TOKEN:
 			case IMAP_TOK_STRING:
@@ -175,7 +415,7 @@ imap_parse_capability(CamelIMAPXStream *stream, CamelException *ex)
 			case IMAP_TOK_INT:
 				printf(" cap: '%s'\n", token);
 				for (i = 0; i < G_N_ELEMENTS (capa_table); i++)
-					if (!strcmp(token, capa_table[i].name))
+					if (!strcmp((gchar *) token, capa_table[i].name))
 						cinfo->capa |= capa_table[i].flag;
 				if (free_token) {
 					g_free (token);
@@ -207,8 +447,9 @@ imap_parse_namespace_list (CamelIMAPXStream *stream, CamelException *ex)
 {
 	CamelIMAPXStoreNamespace *namespaces[3], *node, *tail;
 	CamelIMAPXNamespaceList *nsl = NULL;
-	gint tok, len, i;
-	guchar *token, *p, c;
+	gint tok, i;
+	guint len;
+	guchar *token;
 	gint n = 0;
 
 	nsl = g_malloc0(sizeof(CamelIMAPXNamespaceList));
@@ -233,14 +474,14 @@ imap_parse_namespace_list (CamelIMAPXStream *stream, CamelException *ex)
 
 				node = g_new0 (CamelIMAPXStoreNamespace, 1);
 				node->next = NULL;
-				node->full_name = g_strdup (token);
-				node->path = g_strdup (token);
+				node->full_name = g_strdup ((gchar *) token);
+				node->path = g_strdup ((gchar *) token);
 				g_message ("namespace: Node path is %s \n", node->path);
 
 				tok = camel_imapx_stream_token (stream, &token, &len, ex);
 
 				if (tok == IMAP_TOK_STRING) {
-					if (strlen (token) == 1) {
+					if (strlen ((gchar *) token) == 1) {
 						node->sep = *token;
 					} else {
 						if (*token)
@@ -281,7 +522,7 @@ imap_parse_namespace_list (CamelIMAPXStream *stream, CamelException *ex)
 				goto exception;
 			}
 
-		} else if (tok == IMAP_TOK_TOKEN && !strcmp (token, "NIL")) {
+		} else if (tok == IMAP_TOK_TOKEN && !strcmp ((gchar *) token, "NIL")) {
 			namespaces [n] = NULL;
 		} else {
 			camel_exception_set (ex, 1, "namespace: expected either a '(' or NIL");
@@ -446,8 +687,10 @@ imap_free_body(struct _CamelMessageContentInfo *cinfo)
 void
 imap_parse_param_list(CamelIMAPXStream *is, struct _camel_header_param **plist, CamelException *ex)
 {
-	gint tok, len;
-	guchar *token, *param;
+	gint tok;
+	guint len;
+	guchar *token;
+	gchar *param;
 
 	p(printf("body_fld_param\n"));
 
@@ -461,10 +704,10 @@ imap_parse_param_list(CamelIMAPXStream *is, struct _camel_header_param **plist,
 			camel_imapx_stream_ungettoken(is, tok, token, len);
 
 			camel_imapx_stream_astring(is, &token, ex);
-			param = alloca(strlen(token)+1);
-			strcpy(param, token);
+			param = alloca (strlen ((gchar *) token)+1);
+			strcpy(param, (gchar *) token);
 			camel_imapx_stream_astring(is, &token, ex);
-			camel_header_set_param(plist, param, token);
+			camel_header_set_param(plist, param, (gchar *) token);
 		}
 	} /* else check nil?  no need */
 }
@@ -472,7 +715,8 @@ imap_parse_param_list(CamelIMAPXStream *is, struct _camel_header_param **plist,
 struct _CamelContentDisposition *
 imap_parse_ext_optional(CamelIMAPXStream *is, CamelException *ex)
 {
-	gint tok, len;
+	gint tok;
+	guint len;
 	guchar *token;
 	struct _CamelContentDisposition *dinfo = NULL;
 
@@ -501,7 +745,7 @@ imap_parse_ext_optional(CamelIMAPXStream *is, CamelException *ex)
 			/* should be string */
 			camel_imapx_stream_astring(is, &token, ex);
 
-			dinfo->disposition = g_strdup(token);
+			dinfo->disposition = g_strdup((gchar *) token);
 			imap_parse_param_list(is, &dinfo->params, ex);
 		case IMAP_TOK_TOKEN:
 			d(printf("body_fld_dsp: NIL\n"));
@@ -558,7 +802,8 @@ imap_parse_ext_optional(CamelIMAPXStream *is, CamelException *ex)
 struct _CamelMessageContentInfo *
 imap_parse_body_fields(CamelIMAPXStream *is, CamelException *ex)
 {
-	guchar *token, *type;
+	guchar *token;
+	gchar  *type;
 	struct _CamelMessageContentInfo *cinfo;
 
 	/* body_fields     ::= body_fld_param SPACE body_fld_id SPACE
@@ -573,12 +818,12 @@ imap_parse_body_fields(CamelIMAPXStream *is, CamelException *ex)
 	camel_imapx_stream_astring(is, &token, ex);
 	if (camel_exception_is_set (ex))
 		goto error;
-	type = alloca(strlen(token)+1);
-	strcpy(type, token);
+	type = alloca(strlen( (gchar *) token)+1);
+	strcpy(type, (gchar *) token);
 	camel_imapx_stream_astring(is, &token, ex);
 	if (camel_exception_is_set (ex))
 		goto error;
-	cinfo->type = camel_content_type_new(type, token);
+	cinfo->type = camel_content_type_new(type, (gchar *) token);
 	imap_parse_param_list(is, &cinfo->type->params, ex);
 	if (camel_exception_is_set (ex))
 		goto error;
@@ -587,20 +832,20 @@ imap_parse_body_fields(CamelIMAPXStream *is, CamelException *ex)
 	camel_imapx_stream_nstring(is, &token, ex);
 	if (camel_exception_is_set (ex))
 		goto error;
-	cinfo->id = g_strdup(token);
+	cinfo->id = g_strdup((gchar *) token);
 
 	/* body_fld_desc   ::= nstring */
 	camel_imapx_stream_nstring(is, &token, ex);
 	if (camel_exception_is_set (ex))
 		goto error;
-	cinfo->description = g_strdup(token);
+	cinfo->description = g_strdup((gchar *) token);
 
 	/* body_fld_enc    ::= (<"> ("7BIT" / "8BIT" / "BINARY" / "BASE64"/
 	   "QUOTED-PRINTABLE") <">) / string */
 	camel_imapx_stream_astring(is, &token, ex);
 	if (camel_exception_is_set (ex))
 		goto error;
-	cinfo->encoding = g_strdup(token);
+	cinfo->encoding = g_strdup((gchar *) token);
 
 	/* body_fld_octets ::= number */
 	cinfo->size = camel_imapx_stream_number(is, ex);
@@ -617,8 +862,10 @@ struct _camel_header_address *
 imap_parse_address_list(CamelIMAPXStream *is, CamelException *ex)
 /* throws PARSE,IO exception */
 {
-	gint tok, len;
-	guchar *token, *host, *mbox;
+	gint tok;
+	guint len;
+	guchar *token, *host;
+	gchar *mbox;
 	struct _camel_header_address *list = NULL;
 
 	/* "(" 1*address ")" / nil */
@@ -642,7 +889,7 @@ imap_parse_address_list(CamelIMAPXStream *is, CamelException *ex)
 			addr = camel_header_address_new();
 			addr->type = CAMEL_HEADER_ADDRESS_NAME;
 			tok = camel_imapx_stream_nstring(is, &token, ex);
-			addr->name = g_strdup(token);
+			addr->name = g_strdup((gchar *) token);
 			/* we ignore the route, nobody uses it in the real world */
 			tok = camel_imapx_stream_nstring(is, &token, ex);
 
@@ -654,7 +901,7 @@ imap_parse_address_list(CamelIMAPXStream *is, CamelException *ex)
 			   non-NIL, this is a start of group marker, and the
 			   mailbox name field holds the group name phrase. */
 
-			tok = camel_imapx_stream_nstring(is, &mbox, ex);
+			tok = camel_imapx_stream_nstring(is,(guchar **) &mbox, ex);
 			mbox = g_strdup(mbox);
 			tok = camel_imapx_stream_nstring(is, &host, ex);
 			if (host == NULL) {
@@ -669,7 +916,7 @@ imap_parse_address_list(CamelIMAPXStream *is, CamelException *ex)
 					group = addr;
 				}
 			} else {
-				addr->v.addr = g_strdup_printf("%s%s%s", mbox?(gchar *)mbox:"", host?"@":"", host?(gchar *)host:"");
+				addr->v.addr = g_strdup_printf("%s%s%s", mbox? mbox:"", host?"@":"", host?(gchar *)host:"");
 				g_free(mbox);
 				d(printf("adding address '%s'\n", addr->v.addr));
 				if (group != NULL)
@@ -693,7 +940,8 @@ imap_parse_address_list(CamelIMAPXStream *is, CamelException *ex)
 struct _CamelMessageInfo *
 imap_parse_envelope(CamelIMAPXStream *is, CamelException *ex)
 {
-	gint tok, len;
+	gint tok;
+	guint len;
 	guchar *token;
 	struct _camel_header_address *addr, *addr_from;
 	gchar *addrstr;
@@ -717,11 +965,11 @@ imap_parse_envelope(CamelIMAPXStream *is, CamelException *ex)
 
 	/* env_date        ::= nstring */
 	camel_imapx_stream_nstring(is, &token, ex);
-	minfo->date_sent = camel_header_decode_date(token, NULL);
+	minfo->date_sent = camel_header_decode_date((gchar *) token, NULL);
 
 	/* env_subject     ::= nstring */
 	tok = camel_imapx_stream_nstring(is, &token, ex);
-	minfo->subject = camel_pstring_strdup(token);
+	minfo->subject = camel_pstring_strdup((gchar *) token);
 
 	/* we merge from/sender into from, append should probably merge more smartly? */
 
@@ -791,7 +1039,7 @@ imap_parse_envelope(CamelIMAPXStream *is, CamelException *ex)
 	tok = camel_imapx_stream_token(is, &token, &len, ex);
 	if (tok != ')') {
 		camel_message_info_free(minfo);
-		camel_exception_throw(1, "expecting ')'");
+		camel_exception_set (ex, 1, "expecting ')'");
 		return NULL;
 	}
 
@@ -803,12 +1051,13 @@ imap_parse_envelope(CamelIMAPXStream *is, CamelException *ex)
 struct _CamelMessageContentInfo *
 imap_parse_body(CamelIMAPXStream *is, CamelException *ex)
 {
-	gint tok, len;
+	gint tok;
+	guint len;
 	guchar *token;
-	struct _CamelMessageContentInfo * volatile cinfo = NULL;
+	struct _CamelMessageContentInfo * cinfo = NULL;
 	struct _CamelMessageContentInfo *subinfo, *last;
-	struct _CamelContentDisposition * volatile dinfo = NULL;
-	struct _CamelMessageInfo * volatile minfo = NULL;
+	struct _CamelContentDisposition * dinfo = NULL;
+	struct _CamelMessageInfo * minfo = NULL;
 
 	/* body            ::= "(" body_type_1part / body_type_mpart ")" */
 
@@ -841,7 +1090,7 @@ imap_parse_body(CamelIMAPXStream *is, CamelException *ex)
 		d(printf("media_subtype\n"));
 
 		camel_imapx_stream_astring(is, &token, ex);
-		cinfo->type = camel_content_type_new("multipart", token);
+		cinfo->type = camel_content_type_new("multipart", (gchar *) token);
 
 		/* body_ext_mpart  ::= body_fld_param
 		   [SPACE body_fld_dsp SPACE body_fld_lang
@@ -933,8 +1182,9 @@ imap_parse_body(CamelIMAPXStream *is, CamelException *ex)
 	/* there should only be simple tokens, no lists */
 	do {
 		tok = camel_imapx_stream_token(is, &token, &len, ex);
-		if (tok != ')')
+		if (tok != ')') {
 			d(printf("Dropping extension data '%s'\n", token));
+		}
 	} while (tok != ')');
 
 	/* CHEN TODO handle exceptions better */
@@ -958,7 +1208,8 @@ imap_parse_body(CamelIMAPXStream *is, CamelException *ex)
 gchar *
 imap_parse_section(CamelIMAPXStream *is, CamelException *ex)
 {
-	gint tok, len;
+	gint tok;
+	guint len;
 	guchar *token;
 	gchar * section = NULL;
 
@@ -981,7 +1232,7 @@ imap_parse_section(CamelIMAPXStream *is, CamelException *ex)
 
 	tok = camel_imapx_stream_token(is, &token, &len, ex);
 	if (tok == IMAP_TOK_INT || tok == IMAP_TOK_TOKEN)
-		section = g_strdup(token);
+		section = g_strdup((gchar *) token);
 	else if (tok == ']') {
 		section = g_strdup("");
 		camel_imapx_stream_ungettoken(is, tok, token, len);
@@ -1041,8 +1292,6 @@ imap_free_fetch(struct _fetch_info *finfo)
 	g_free(finfo);
 }
 
-extern void camel_message_info_dump(CamelMessageInfo *mi);
-
 #include <camel/camel-stream-fs.h>
 
 /* debug, dump one out */
@@ -1101,7 +1350,8 @@ imap_dump_fetch(struct _fetch_info *finfo)
 struct _fetch_info *
 imap_parse_fetch(CamelIMAPXStream *is, CamelException *ex)
 {
-	gint tok, len;
+	gint tok;
+	guint len;
 	guchar *token, *p, c;
 	struct _fetch_info *finfo;
 
@@ -1120,7 +1370,7 @@ imap_parse_fetch(CamelIMAPXStream *is, CamelException *ex)
 		while ((c=*p))
 			*p++ = toupper(c);
 
-		switch (imap_tokenise(token, len)) {
+		switch (imap_tokenise((gchar *) token, len)) {
 			case IMAP_ENVELOPE:
 				finfo->minfo = imap_parse_envelope(is, ex);
 				finfo->got |= FETCH_MINFO;
@@ -1132,7 +1382,7 @@ imap_parse_fetch(CamelIMAPXStream *is, CamelException *ex)
 			case IMAP_INTERNALDATE:
 				camel_imapx_stream_nstring(is, &token, ex);
 				/* TODO: convert to camel format? */
-				finfo->date = g_strdup(token);
+				finfo->date = g_strdup((gchar *) token);
 				finfo->got |= FETCH_DATE;
 				break;
 			case IMAP_RFC822_HEADER:
@@ -1162,7 +1412,7 @@ imap_parse_fetch(CamelIMAPXStream *is, CamelException *ex)
 					finfo->got |= FETCH_SECTION;
 					tok = camel_imapx_stream_token(is, &token, &len, ex);
 					if (token[0] == '<') {
-						finfo->offset = strtoul(token+1, NULL, 10);
+						finfo->offset = strtoul((gchar *) token+1, NULL, 10);
 					} else {
 						camel_imapx_stream_ungettoken(is, tok, token, len);
 					}
@@ -1180,7 +1430,7 @@ imap_parse_fetch(CamelIMAPXStream *is, CamelException *ex)
 					camel_exception_set (ex, 1, "uid not integer");
 				}
 
-				finfo->uid = g_strdup(token);
+				finfo->uid = g_strdup((gchar *) token);
 				finfo->got |= FETCH_UID;
 				break;
 			default:
@@ -1199,12 +1449,66 @@ imap_parse_fetch(CamelIMAPXStream *is, CamelException *ex)
 	return finfo;
 }
 
+struct _state_info *
+imap_parse_status_info (struct _CamelIMAPXStream *is, CamelException *ex)
+{
+	struct _state_info *sinfo;
+	gint tok;
+	guint len;
+	guchar *token;
+
+	sinfo = g_malloc0 (sizeof(*sinfo));
+
+	/* skip the folder name */
+	camel_imapx_stream_token (is, &token, &len, ex);
+
+	tok = camel_imapx_stream_token(is, &token, &len, ex);
+	if (tok != '(') {
+		camel_exception_set (ex, 1, "parse status info: expecting '('");
+		g_free (sinfo);
+		return NULL;
+	}
+
+	while ( (tok = camel_imapx_stream_token(is, &token, &len, ex)) == IMAP_TOK_TOKEN ) {
+		switch (imap_tokenise((gchar *) token, len)) {
+			case IMAP_MESSAGES:
+				sinfo->messages = camel_imapx_stream_number (is, ex);
+				break;
+			case IMAP_RECENT:
+				sinfo->recent = camel_imapx_stream_number (is, ex);
+				break;
+			case IMAP_UIDNEXT:
+				sinfo->uidnext = camel_imapx_stream_number (is, ex);
+				break;
+			case IMAP_UIDVALIDITY:
+				sinfo->uidvalidity = camel_imapx_stream_number (is, ex);
+				break;
+			case IMAP_UNSEEN:
+				sinfo->unseen = camel_imapx_stream_number (is, ex);
+				break;
+			default:
+				g_free (sinfo);
+				camel_exception_set (ex, 1, "unknown status response");
+				return NULL;
+		}
+	}
+
+	if (tok != ')') {
+		camel_exception_set (ex, 1, "missing closing ')' on status response");
+		g_free (sinfo);
+		return NULL;
+	}
+
+	return sinfo;
+}
+
 /* rfc 2060 section 7.1 Status Responses */
 /* shoudl this start after [ or before the [? token_unget anyone? */
 struct _status_info *
 imap_parse_status(CamelIMAPXStream *is, CamelException *ex)
 {
-	gint tok, len;
+	gint tok;
+	guint len;
 	guchar *token;
 	struct _status_info *sinfo;
 
@@ -1222,7 +1526,7 @@ imap_parse_status(CamelIMAPXStream *is, CamelException *ex)
 	   ;; Status condition
 	 */
 
-	sinfo->result = imap_tokenise(token, len);
+	sinfo->result = imap_tokenise((gchar *) token, len);
 	switch (sinfo->result) {
 		case IMAP_OK:
 		case IMAP_NO:
@@ -1239,7 +1543,7 @@ imap_parse_status(CamelIMAPXStream *is, CamelException *ex)
 	tok = camel_imapx_stream_token(is, &token, &len, ex);
 	if (tok == '[') {
 		camel_imapx_stream_atom(is, &token, &len, ex);
-		sinfo->condition = imap_tokenise(token, len);
+		sinfo->condition = imap_tokenise((gchar *) token, len);
 
 		/* parse any details */
 		switch (sinfo->condition) {
@@ -1256,9 +1560,9 @@ imap_parse_status(CamelIMAPXStream *is, CamelException *ex)
 			case IMAP_NEWNAME:
 				/* the rfc doesn't specify the bnf for this */
 				camel_imapx_stream_astring(is, &token, ex);
-				sinfo->u.newname.oldname = g_strdup(token);
+				sinfo->u.newname.oldname = g_strdup((gchar *) token);
 				camel_imapx_stream_astring(is, &token, ex);
-				sinfo->u.newname.newname = g_strdup(token);
+				sinfo->u.newname.newname = g_strdup((gchar *) token);
 				break;
 			case IMAP_PERMANENTFLAGS:
 				/* we only care about \* for permanent flags, not user flags */
@@ -1267,6 +1571,9 @@ imap_parse_status(CamelIMAPXStream *is, CamelException *ex)
 			case IMAP_UIDVALIDITY:
 				sinfo->u.uidvalidity = camel_imapx_stream_number(is, ex);
 				break;
+			case IMAP_UIDNEXT:
+				sinfo->u.uidnext = camel_imapx_stream_number (is, ex);
+				break;
 			case IMAP_UNSEEN:
 				sinfo->u.unseen = camel_imapx_stream_number(is, ex);
 				break;
@@ -1331,7 +1638,7 @@ imap_free_status(struct _status_info *sinfo)
 /* FIXME: use tokeniser? */
 /* FIXME: real flags */
 static struct {
-	gchar *name;
+	const gchar *name;
 	guint32 flag;
 } list_flag_table[] = {
 	{ "\\NOINFERIORS", CAMEL_FOLDER_NOINFERIORS },
@@ -1344,7 +1651,8 @@ struct _list_info *
 imap_parse_list(CamelIMAPXStream *is, CamelException *ex)
 /* throws io, parse */
 {
-	gint tok, len, i;
+	gint tok, i;
+	guint len;
 	guchar *token, *p, c;
 	struct _list_info * linfo;
 
@@ -1367,7 +1675,7 @@ imap_parse_list(CamelIMAPXStream *is, CamelException *ex)
 			while ((c=*p))
 				*p++ = toupper(c);
 			for (i = 0; i < G_N_ELEMENTS (list_flag_table); i++)
-				if (!strcmp(token, list_flag_table[i].name))
+				if (!strcmp((gchar *) token, list_flag_table[i].name))
 					linfo->flags |= list_flag_table[i].flag;
 		} else {
 			imap_free_list(linfo);
@@ -1379,7 +1687,7 @@ imap_parse_list(CamelIMAPXStream *is, CamelException *ex)
 	camel_imapx_stream_nstring(is, &token, ex);
 	linfo->separator = token?*token:0;
 	camel_imapx_stream_astring(is, &token, ex);
-	linfo->name = g_strdup(token);
+	linfo->name = g_strdup((gchar *) token);
 
 	return linfo;
 }
@@ -1627,3 +1935,20 @@ camel_imapx_namespace_list_copy (const struct _CamelIMAPXNamespaceList *nsl)
 
 	return new;
 }
+
+gchar *
+imapx_get_temp_uid (void)
+{
+	gchar *res;
+
+	static gint counter = 0;
+	G_LOCK_DEFINE_STATIC (lock);
+
+	G_LOCK (lock);
+	res = g_strdup_printf ("tempuid-%lx-%d",
+			       (gulong) time (NULL),
+			       counter++);
+	G_UNLOCK (lock);
+
+	return res;
+}
