@@ -1,15 +1,15 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-pop3-folder.h : Class for a POP3 folder */
 
-/* 
+/*
  * Authors:
  *   Dan Winship <danw@ximian.com>
  *   Michael Zucchi <notzed@ximian.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -40,8 +40,8 @@ typedef struct {
 	guint32 size;
 	guint32 flags;
 	guint32 index;		/* index of request */
-	char *uid;
-	int err;
+	gchar *uid;
+	gint err;
 	struct _CamelPOP3Command *cmd;
 	struct _CamelStream *stream;
 } CamelPOP3FolderInfo;
@@ -57,8 +57,8 @@ typedef struct {
 typedef struct {
 	CamelFolderClass parent_class;
 
-	/* Virtual methods */	
-	
+	/* Virtual methods */
+
 } CamelPOP3FolderClass;
 
 /* public methods */
@@ -67,7 +67,7 @@ CamelFolder *camel_pop3_folder_new (CamelStore *parent, CamelException *ex);
 /* Standard Camel function */
 CamelType camel_pop3_folder_get_type (void);
 
-int camel_pop3_delete_old(CamelFolder *folder, int days_to_delete, CamelException *ex);
+gint camel_pop3_delete_old(CamelFolder *folder, gint days_to_delete, CamelException *ex);
 
 G_END_DECLS
 
